/// <reference types="node" />
import { Readable, ReadableOptions } from "node:stream";
export declare class ExtendedAsyncIterable<A> implements AsyncIterable<A>, AsyncIterator<A> {
    wrapped: AsyncIterable<A>;
    id: number;
    getDebugName: () => string;
    cachedIterator?: AsyncIterator<A>;
    constructor(wrapped: AsyncIterable<A>);
    [Symbol.asyncIterator](): AsyncIterator<A>;
    next(): Promise<IteratorResult<A>>;
    map<B>(f: (item: A) => (B | Promise<B>)): ExtendedAsyncIterable<B>;
    flatMap<B>(f: (item: A) => AsyncIterable<B>): ExtendedAsyncIterable<B>;
    filter(f: (item: A) => boolean): ExtendedAsyncIterable<A>;
    filterMap<B>(f: (item: A) => B | undefined): ExtendedAsyncIterable<B>;
    find(f: (item: A) => boolean): Promise<A | undefined>;
    some(f: (item: A) => boolean): Promise<boolean>;
    every(f: (item: A) => boolean): Promise<boolean>;
    reduce<B>(f: (sum: B, item: A) => B, start: B): Promise<B>;
    collect(): Promise<A[]>;
    chain(iter: AsyncIterable<A>): ExtendedAsyncIterable<A>;
    static chainAll<A>(iters: AsyncIterable<A>[]): ExtendedAsyncIterable<A>;
    zip<B>(iter: AsyncIterable<B>): ExtendedAsyncIterable<[A, B]>;
    merge<B>(...iterables: AsyncIterable<B>[]): ExtendedAsyncIterable<A | B>;
    static mergeAll<A>(iterables: AsyncIterable<A>[]): ExtendedAsyncIterable<A>;
    enumerate(): ExtendedAsyncIterable<[number, A]>;
    splitWhen(f: (item: A) => boolean): [ExtendedAsyncIterable<A>, ExtendedAsyncIterable<A>];
    tee(count?: number): ExtendedAsyncIterable<A>[];
    partition(f: (item: A) => boolean): [ExtendedAsyncIterable<A>, ExtendedAsyncIterable<A>];
    takeWhile(f: (item: A) => boolean): ExtendedAsyncIterable<A>;
    take(n: number): ExtendedAsyncIterable<A>;
    takeFor(msec: number): ExtendedAsyncIterable<A>;
    takeUntil(deadline: number): ExtendedAsyncIterable<A>;
    dropWhile(f: (item: A) => boolean): ExtendedAsyncIterable<A>;
    drop(n: number): ExtendedAsyncIterable<A>;
    after(f: () => Promise<void>): ExtendedAsyncIterable<A>;
    withPromiseAfter(): [ExtendedAsyncIterable<A>, Promise<void>];
    toString(): string;
    toNodeStream(options?: ReadableOptions): Readable;
}
export type VaguelyIterable<A> = AsyncIterable<A> | AsyncIterator<A> | Iterable<A>;
export declare function asyncIter<A>(iter: VaguelyIterable<A>, getDebugName?: () => string): ExtendedAsyncIterable<A>;
